<p align="center">
  <img alt="Logo" src="https://github.com/Radonirinaunimi/pwnd-check/blob/master/logo/logo.png" width=500>
</p>
<p align="center">
  <img alt="License" src="https://img.shields.io/github/license/Radonirinaunimi/python-template?style=flat-square">
  <img alt="repo size" src="https://img.shields.io/github/repo-size/Radonirinaunimi/python-template?style=flat-square">
  <img alt="release" src="https://img.shields.io/github/v/release/Radonirinaunimi/pwnd-check?label=release&logo=Github&style=flat-square">
  <img alt="coverage" src="https://img.shields.io/codecov/c/github/Radonirinaunimi/pwnd-check/backbone?style=flat-square">
</p>

### CheckPwd

This package allows you to check if at some point your passwords have been leaked. If that is the case, your passwords are more likely to appear in a long list of dictionary that is used for hacking. This, then makes your accounts, data, and credentials much more vulnerable. To put in another way, if your password has been leaked before, it is no longer safe to use.


### Installation

The package can be installed via the Python Package Index (PyPI) by running:
```bash
pip install checkpwd --upgrade
```

### Documentation

For further details, check the [documentation](https://radonirinaunimi.github.io/pwnd-check/).
